==> haskell-hls-explicit-fixity-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-fixity-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-2.1.0.0-7AYgGN9Vnmj8Bg3lQBgcvR
key:                  hls-explicit-fixity-plugin-2.1.0.0-7AYgGN9Vnmj8Bg3lQBgcvR
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  e4db559dfdcb6832f4869d0801f1e71f
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-2.1.0.0-7AYgGN9Vnmj8Bg3lQBgcvR
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    extra-1.7.16-KxrHBQWVwMp2M62XitBte8 ghc-9.4.8
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-fixity-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-fixity-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-2.1.0.0-27XdeJTCsp24YHvbwxf8qf
key:                  hls-explicit-fixity-plugin-2.1.0.0-27XdeJTCsp24YHvbwxf8qf
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  72c1ae43253333f12ec1d34c5a34dc86
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-2.1.0.0-27XdeJTCsp24YHvbwxf8qf
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E ghc-9.4.8
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
